# OpenTimelineIO Contrib Area

The contrib area was a place to host adapters and application plugins submitted
by the OpenTimelineIO community. Those contributions may have involved challenging external 
dependencies, and may not have the same level of support as the core.

The adapters previously found in the contrib area have been moved to individual
repos within the
[OpenTimelineIO GitHub Organization](https://github.com/OpenTimelineIO/).

New contributions should be created in standalone repos, and those can later be
migrated to the OTIO GitHub organization after review.

## Creating New Contrib Adapters and Plugins

The best way to get started is to go to the
[otio-plugin-template repo](https://github.com/OpenTimelineIO/otio-plugin-template)
and click "Use this template". This will get you started with plugin boilerplate
and allow you to develop the adapter in your own GitHub account.

Once you've developed your plugin, please contact the
[OpenTimelineIO team](https://github.com/AcademySoftwareFoundation/OpenTimelineIO)
to talk about next steps for the plugin.
